<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk_UA" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <location filename="src/aboutview.cpp" line="58"/>
        <source>There&apos;s life outside the browser!</source>
        <translation>За межами оглядача тенет також є життя!</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="59"/>
        <source>Version %1</source>
        <translation>Версія %1</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="64"/>
        <source>Licensed to: %1</source>
        <translation>Ліцензія належить: %1</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="68"/>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 — вільне проґрамне забезпечення, але на його розробку було затрачено коштовний час.</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="69"/>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Будь ласка, &lt;a href=&apos;%1&apos;&gt;внесіть пожертву,&lt;/a&gt; аби підтримати подальший розвиток %2.</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="73"/>
        <source>You may want to try my other apps as well:</source>
        <translation>Спробуйте інші проґрами:</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="76"/>
        <source>%1, a YouTube music player</source>
        <translation>%1, музичний програвач для YouTube </translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="80"/>
        <source>%1, a music player</source>
        <translation>%1, музичний програвач</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="86"/>
        <source>Translate %1 to your native language using %2</source>
        <translation>Перекласти %1 Вашою рідною мовою за допомогою %2</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="91"/>
        <source>Icon designed by %1.</source>
        <translation>Розробник піктоґрам %1.</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="95"/>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Випущено за &lt;a href=&apos;%1&apos;&gt;Загальною громадською ліцензією GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="110"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрити</translation>
    </message>
    <message>
        <location filename="src/aboutview.h" line="40"/>
        <source>About</source>
        <translation>Про проґраму</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <location filename="local/src/activationdialog.cpp" line="17"/>
        <source>Enter your License Details</source>
        <translation>Уведіть дані Вашої ліцензії</translation>
    </message>
    <message>
        <location filename="local/src/activationdialog.cpp" line="29"/>
        <source>&amp;Email:</source>
        <translation>&amp;Email:</translation>
    </message>
    <message>
        <location filename="local/src/activationdialog.cpp" line="35"/>
        <source>&amp;Code:</source>
        <translation>&amp;Код:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <location filename="local/src/activationview.cpp" line="47"/>
        <source>Please license %1</source>
        <translation>	
Ліцензуйте %1</translation>
    </message>
    <message>
        <location filename="local/src/activationview.cpp" line="51"/>
        <source>This demo has expired.</source>
        <translation>Пробний період вичерпано.</translation>
    </message>
    <message>
        <location filename="local/src/activationview.cpp" line="53"/>
        <source>The full version allows you to watch videos without interruptions.</source>
        <oldsource>The full version allows you to download videos longer than %1 minutes and to watch videos without interruptions.</oldsource>
        <translation>Повна версія дозволяє дивитися видиво без перерв.</translation>
    </message>
    <message>
        <location filename="local/src/activationview.cpp" line="55"/>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Проґраму буде заблоковано через %1 днів, якщо Ви не придбаєте ліцензію.</translation>
    </message>
    <message>
        <location filename="local/src/activationview.cpp" line="57"/>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>При купівлі повної версії, Ви, також, надаєте підтримку важкій роботі, яка була задіяна під час створення %1.</translation>
    </message>
    <message>
        <location filename="local/src/activationview.cpp" line="70"/>
        <source>Use Demo</source>
        <translation>Демонстрація</translation>
    </message>
    <message>
        <location filename="local/src/activationview.cpp" line="77"/>
        <source>Enter License</source>
        <translation>Увести ліцензію</translation>
    </message>
    <message>
        <location filename="local/src/activationview.cpp" line="85"/>
        <source>Buy License</source>
        <translation>Придбати ліцензію</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <location filename="src/channelaggregator.cpp" line="183"/>
        <source>By %1</source>
        <translation>За %1</translation>
    </message>
    <message numerus="yes">
        <location filename="src/channelaggregator.cpp" line="185"/>
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <location filename="src/channelitemdelegate.cpp" line="67"/>
        <source>All Videos</source>
        <translation>Усі видива</translation>
    </message>
    <message>
        <location filename="src/channelitemdelegate.cpp" line="85"/>
        <source>Unwatched Videos</source>
        <translation>Не переглянуті видива</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <location filename="src/channelview.cpp" line="151"/>
        <source>Mark all as watched</source>
        <translation>Позначити все переглянутим</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="159"/>
        <source>Show Updated</source>
        <translation>Показати оновлені</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="103"/>
        <source>Name</source>
        <translation>Назва</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="110"/>
        <source>Last Updated</source>
        <translation>Нещодавно оновлені</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="117"/>
        <source>Last Added</source>
        <translation>Нещодавно додані</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="124"/>
        <source>Last Watched</source>
        <translation>Нещодавно переглянуті</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="131"/>
        <source>Most Watched</source>
        <translation>Найбільш переглядаюче</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="139"/>
        <source>Sort by</source>
        <translation>Сортувати за</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="222"/>
        <source>All Videos</source>
        <translation>Усі видива</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="226"/>
        <source>Unwatched Videos</source>
        <translation>Не переглянуті видива</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="244"/>
        <source>Mark as Watched</source>
        <translation>Позначити як переглянуте</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="257"/>
        <source>Unsubscribe</source>
        <translation>Відмовитися від підписки</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="270"/>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Наразі оновлень підписок немає.</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="272"/>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>У Вас немає підписок. Використовуйте символ зірочки, аби підписуватися на канали.</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <location filename="src/exlineedit.cpp" line="6"/>
        <source>Clear</source>
        <translation>Очистити</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <location filename="src/datautils.cpp" line="88"/>
        <source>Just now</source>
        <translation>Тільки зараз</translation>
    </message>
    <message numerus="yes">
        <location filename="src/datautils.cpp" line="90"/>
        <source>%n minute(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <location filename="src/datautils.cpp" line="92"/>
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <location filename="src/datautils.cpp" line="94"/>
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <location filename="src/datautils.cpp" line="96"/>
        <source>%n weeks(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <location filename="src/datautils.cpp" line="98"/>
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <location filename="src/downloaditem.cpp" line="406"/>
        <source>bytes</source>
        <translation>байтів</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="409"/>
        <source>KB</source>
        <translation>КБ</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="412"/>
        <source>MB</source>
        <translation>МБ</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="421"/>
        <source>bytes/sec</source>
        <translation>байтів/сек</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="424"/>
        <source>KB/sec</source>
        <translation>КБ/сек</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="427"/>
        <source>MB/sec</source>
        <translation>МБ/сек</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="433"/>
        <source>seconds</source>
        <translation>секунд</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="436"/>
        <source>minutes</source>
        <translation>хвилин</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="439"/>
        <source>%4 %5 remaining</source>
        <translation>залишилося %4 %5</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <location filename="src/downloadmanager.cpp" line="77"/>
        <source>This is just the demo version of %1.</source>
        <translation>Це демонстраційна версія %1.</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="79"/>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation>Із метою тестування, Ви можете завантажити видиво тривалістю до %1 хв. </translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="85"/>
        <source>Continue</source>
        <translation>Продовжити</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="86"/>
        <source>Get the full version</source>
        <translation>Отримати повну версію</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="157"/>
        <source>%1 downloaded in %2</source>
        <translation>%1 завантажений до %2</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="160"/>
        <source>Download finished</source>
        <translation>Завантаження завершено</translation>
    </message>
    <message numerus="yes">
        <location filename="src/downloadmanager.cpp" line="165"/>
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <location filename="src/downloadsettings.cpp" line="36"/>
        <source>Change location...</source>
        <translation>Змінити теку для завантаження...</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="69"/>
        <source>Choose the download location</source>
        <translation>Оберіть теку для завантаження</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="81"/>
        <source>Download location changed.</source>
        <translation>Теку завантаження змінено.</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="83"/>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Поточні завантаження буде, як і раніше, збережено у попередньому місці.</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="94"/>
        <source>Downloading to: %1</source>
        <translation>Завантажується до %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <location filename="src/downloadview.cpp" line="38"/>
        <location filename="src/downloadview.h" line="45"/>
        <source>Downloads</source>
        <translation>Завантаження</translation>
    </message>
</context>
<context>
    <name>DownloadWidget</name>
    <message>
        <location filename="local/src/updatedialog.cpp" line="60"/>
        <source>Downloading update...</source>
        <translation>Завантаження оновлення...</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <location filename="local/src/extra.cpp" line="251"/>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="local/src/extra.cpp" line="252"/>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 не буде працювати. Спробуйте встановити заново</translation>
    </message>
    <message>
        <location filename="local/src/extra.cpp" line="253"/>
        <source>Quit</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <location filename="local/src/extra.cpp" line="254"/>
        <source>Reinstall</source>
        <translation>Перевстановити</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <location filename="src/globalshortcuts.cpp" line="36"/>
        <source>Play</source>
        <translation>Грати</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="37"/>
        <source>Pause</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="38"/>
        <source>Play/Pause</source>
        <translation>Грати/Призупинити</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="39"/>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="40"/>
        <source>Stop playing after current track</source>
        <translation>Зупинити після завершення поточного</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="41"/>
        <source>Next track</source>
        <translation>Наступний трек</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="42"/>
        <source>Previous track</source>
        <translation>Попередній трек</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="43"/>
        <source>Increase volume</source>
        <translation>Збільшити гучність</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="44"/>
        <source>Decrease volume</source>
        <translation>Зменшити гучність</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="45"/>
        <source>Mute</source>
        <translation>Приглушити</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="46"/>
        <source>Seek forward</source>
        <translation>Перемотати вперед</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="47"/>
        <source>Seek backward</source>
        <translation>Перемотати назад</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <location filename="src/homeview.cpp" line="58"/>
        <source>Search</source>
        <translation>Шукати</translation>
    </message>
    <message>
        <location filename="src/homeview.cpp" line="60"/>
        <source>Find videos and channels by keyword</source>
        <translation>Знайти видива та канали за ключовими словами</translation>
    </message>
    <message>
        <location filename="src/homeview.cpp" line="65"/>
        <source>Browse</source>
        <translation>Переглянути</translation>
    </message>
    <message>
        <location filename="src/homeview.cpp" line="67"/>
        <source>Browse videos by category</source>
        <translation>Оглянути видива за катеґоріями</translation>
    </message>
    <message>
        <location filename="src/homeview.cpp" line="71"/>
        <source>Subscriptions</source>
        <translation>Підписки</translation>
    </message>
    <message>
        <location filename="src/homeview.cpp" line="73"/>
        <source>Channel subscriptions</source>
        <translation>Підписки на канали</translation>
    </message>
    <message>
        <location filename="src/homeview.h" line="44"/>
        <source>Make yourself comfortable</source>
        <translation>Влаштовуйтесь якнайзручніше</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <location filename="src/loadingwidget.cpp" line="125"/>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="src/mainwindow.cpp" line="291"/>
        <source>&amp;Stop</source>
        <translation>&amp;Зупинити</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="292"/>
        <source>Stop playback and go back to the search view</source>
        <translation>Зупинити відтворення та перейти до вікна пошуку</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="307"/>
        <source>S&amp;kip</source>
        <translation>П&amp;ропустити</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="308"/>
        <source>Skip to the next video</source>
        <translation>Перейти до наступного видива</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1134"/>
        <source>&amp;Pause</source>
        <translation>&amp;Призупинити</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1135"/>
        <source>Pause playback</source>
        <translation>Призупинити відтворення</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="321"/>
        <source>&amp;Full Screen</source>
        <translation>&amp;Повноекранний режим</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="322"/>
        <source>Go full screen</source>
        <translation>Перейти до повноекранного режиму</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="336"/>
        <source>Hide the playlist and the toolbar</source>
        <translation>Сховати перелік та панель інструментів</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="349"/>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Відкрити сторінку YouTube та призупинити відтворення видива</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="356"/>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Скопіювати YouTube посилання поточного видива до буферу</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="363"/>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Скопіювати посилання поточного видива до буферу</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="370"/>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Знайти інші частини видива, сподіваюся, у правильному порядку</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="376"/>
        <source>&amp;Remove</source>
        <translation>&amp;Вилучити</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="377"/>
        <source>Remove the selected videos from the playlist</source>
        <translation>Вилучити обрані видива з переліку</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="383"/>
        <source>Move &amp;Up</source>
        <translation>До&amp;гори</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="384"/>
        <source>Move up the selected videos in the playlist</source>
        <translation>Перемістити обране видиво догори у переліку</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="390"/>
        <source>Move &amp;Down</source>
        <translation>Дони&amp;зу</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="391"/>
        <source>Move down the selected videos in the playlist</source>
        <translation>Перемістити обране видиво донизу в переліку</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="402"/>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Очистити історію пошуку (зміни незворотні).</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="407"/>
        <source>&amp;Quit</source>
        <translation>&amp;Вийти</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="410"/>
        <source>Bye</source>
        <translation>Бувайте</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="414"/>
        <source>&amp;Website</source>
        <translation>&amp;Веб-сайт</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="416"/>
        <source>%1 on the Web</source>
        <translation>%1 у мережі</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="422"/>
        <source>Please support the continued development of %1</source>
        <translation>Будь ласка, підтримайте подальший розвиток %1</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="427"/>
        <source>&amp;About</source>
        <translation>&amp;Про проґраму</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="429"/>
        <source>Info about %1</source>
        <translation>Інформація про %1</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="437"/>
        <source>Search</source>
        <translation>Шукати</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="456"/>
        <source>Mute volume</source>
        <translation>Приглушити гучність</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="490"/>
        <location filename="src/mainwindow.cpp" line="1609"/>
        <source>&amp;Downloads</source>
        <translation>&amp;Завантаження</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="491"/>
        <source>Show details about video downloads</source>
        <translation>Показати деталі про видива, що завантажуються</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="499"/>
        <source>&amp;Download</source>
        <translation>&amp;Завантажити</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="500"/>
        <source>Download the current video</source>
        <translation>Завантажити це видиво</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="510"/>
        <source>Take &amp;Snapshot</source>
        <translation>Зробити &amp;Зняток</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="517"/>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Підписатися на канал</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="525"/>
        <source>Share the current video using %1</source>
        <translation>Поділитися поточним видивом за допомогою %1</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="545"/>
        <source>&amp;Email</source>
        <translation>&amp;Email</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="546"/>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="551"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрити</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="561"/>
        <source>&amp;Float on Top</source>
        <translation>&amp;Згори всіх вікон</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="566"/>
        <source>&amp;Adjust Window Size</source>
        <translation>&amp;Змінити розмір вікна</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="571"/>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Зупинити після цього відео</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="578"/>
        <source>&amp;Report an Issue...</source>
        <translation>По&amp;відомити про помилку</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="582"/>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Уточнити пошук...</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="594"/>
        <source>More...</source>
        <translation>Більше...</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="597"/>
        <source>&amp;Related Videos</source>
        <translation>&amp;Схожі відео</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="599"/>
        <source>Watch videos related to the current one</source>
        <translation>Дивитися відео, пов’язані з поточним</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="605"/>
        <source>Open in &amp;Browser...</source>
        <translation>Відкрити в &amp;оглядачі тенет...</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="612"/>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Подобається %1? Оцініть !</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="633"/>
        <source>&amp;Application</source>
        <translation>&amp;Застосунок</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="618"/>
        <source>Buy %1...</source>
        <translation>Придбати %1...</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="647"/>
        <source>&amp;Playback</source>
        <translation>&amp;Відтворення</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="661"/>
        <source>&amp;Playlist</source>
        <translation>&amp;Перелік відтворення</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="670"/>
        <source>&amp;Video</source>
        <translation>&amp;Відео</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="686"/>
        <source>&amp;View</source>
        <translation>&amp;Переглянути</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="695"/>
        <source>&amp;Share</source>
        <translation>&amp;Поділитися</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="709"/>
        <source>&amp;Help</source>
        <translation>&amp;Довідка</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="751"/>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Натисніть %1, аби приглушити гучність, та %2, щоб її відновити</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1021"/>
        <location filename="src/mainwindow.cpp" line="1027"/>
        <source>Opening %1</source>
        <translation>Відкриття %1</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1080"/>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Триває завантаження, бажаєте закрити %1?</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1081"/>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Якщо закрити %1 негайно, усі завантаження буде скасовано.</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1086"/>
        <source>Close and cancel download</source>
        <translation>Скасувати та закрити</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1087"/>
        <source>Wait for download to finish</source>
        <translation>Дочекатися завершення</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1158"/>
        <source>&amp;Loading...</source>
        <translation>&amp;Завантаження...</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1264"/>
        <source>Leave &amp;Full Screen</source>
        <translation>Вийти з &amp;повноекранного режиму</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1718"/>
        <source>%1 version %2 is now available.</source>
        <translation>%1 версія %2 доступна.</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1722"/>
        <source>Remind me later</source>
        <translation>Нагадати мені пізніше</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1723"/>
        <source>Update</source>
        <translation>Оновлення</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1127"/>
        <source>Error: %1</source>
        <translation>Помилка: %1</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="300"/>
        <source>P&amp;revious</source>
        <translation>По&amp;передній</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="301"/>
        <source>Go back to the previous track</source>
        <translation>Повернутися до попереднього треку</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="335"/>
        <source>&amp;Compact Mode</source>
        <translation>Компак&amp;тний режим</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="348"/>
        <source>Open the &amp;YouTube Page</source>
        <translation>Від&amp;крити сторінку YouTube</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="355"/>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Копіювати &amp;посилання на YouTube</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="362"/>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Копіювати посилання на ві&amp;део-потік</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="369"/>
        <source>Find Video &amp;Parts</source>
        <translation>Знайти &amp;фраґменти видива</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="397"/>
        <source>&amp;Clear Recent Searches</source>
        <translation>О&amp;чистити останні пошукові запити</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="421"/>
        <source>Make a &amp;Donation</source>
        <translation>Підтрима&amp;йте проєкт</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="483"/>
        <source>&amp;Manually Start Playing</source>
        <translation>&amp;Почати відтворення самотужки</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="484"/>
        <source>Manually start playing videos</source>
        <translation>Почати відтворення видива самотужки</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="847"/>
        <source>Choose your content location</source>
        <translation>Оберіть своє місцерозташування</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="314"/>
        <location filename="src/mainwindow.cpp" line="1142"/>
        <location filename="src/mainwindow.cpp" line="1150"/>
        <source>&amp;Play</source>
        <translation>&amp;Грати</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="315"/>
        <location filename="src/mainwindow.cpp" line="1143"/>
        <location filename="src/mainwindow.cpp" line="1151"/>
        <source>Resume playback</source>
        <translation>Відновити відтворення</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1437"/>
        <source>Remaining time: %1</source>
        <translation>Залишилося часу: %1</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1528"/>
        <source>Volume at %1%</source>
        <translation>Гучність %1%</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1534"/>
        <source>Volume is muted</source>
        <translation>Гучність приглушено</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1537"/>
        <source>Volume is unmuted</source>
        <translation>Гучність відновлено</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1548"/>
        <source>Maximum video definition set to %1</source>
        <translation>Режим чіткості видива %1</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1595"/>
        <source>Your privacy is now safe</source>
        <translation>Ваша приватність тепер у безпеці</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1610"/>
        <source>Downloads complete</source>
        <translation>Завантаження завершено</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <location filename="src/mediaview.cpp" line="702"/>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Тепер Ви можете використовувати YouTube посилання на видиво у зовнішній проґрамі</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="710"/>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Тепер Ви можете використовувати посилання на видиво у зовнішній проґрамі</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="711"/>
        <source>The link will be valid only for a limited time.</source>
        <translation>Посилання буде дійсне лише протягом обмеженого часу.</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="800"/>
        <source>This is just the demo version of %1.</source>
        <translation>&gt;Це демонстраційна версія %1.</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="801"/>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation>Ви маєте змогу протестувати проґраму та перевірити працездатність.</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="833"/>
        <source>Continue</source>
        <translation>Продовжити</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="988"/>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>з</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="1001"/>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>частина</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="1003"/>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>епізод</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="1096"/>
        <source>Sent from %1</source>
        <translation>Надіслати з %1</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="1128"/>
        <source>Unsubscribe from %1</source>
        <translation>Відписатися %1</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="1132"/>
        <source>Subscribe to %1</source>
        <translation>Підписуватися на %1</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="1166"/>
        <source>Unsubscribed from %1</source>
        <translation>Підписка на %1 анульована</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="1169"/>
        <source>Subscribed to %1</source>
        <translation>Підписка на %1 оформлена</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="808"/>
        <source>Get the full version</source>
        <translation>Отримати повну версію</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="847"/>
        <source>Downloading %1</source>
        <translation>Завантаження %1</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <location filename="local/src/updatedialog.cpp" line="21"/>
        <source>A new version of %1 is available!</source>
        <translation>Доступна нова версія %1!</translation>
    </message>
    <message>
        <location filename="local/src/updatedialog.cpp" line="28"/>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 доступна. Ви маєте %3.</translation>
    </message>
    <message>
        <location filename="local/src/updatedialog.cpp" line="33"/>
        <source>Would you like to download it now?</source>
        <translation>Бажаєте завантажити це зараз?</translation>
    </message>
    <message>
        <location filename="local/src/updatedialog.cpp" line="39"/>
        <source>Skip This Version</source>
        <translation>Пропустити цю версію</translation>
    </message>
    <message>
        <location filename="local/src/updatedialog.cpp" line="43"/>
        <source>Remind Me Later</source>
        <translation>Нагадати пізніше</translation>
    </message>
    <message>
        <location filename="local/src/updatedialog.cpp" line="47"/>
        <source>Install Update</source>
        <translation>Встановити оновлення</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <location filename="local/src/pastelineedit.cpp" line="6"/>
        <source>Paste</source>
        <translation>Вставити</translation>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <location filename="src/playlistitemdelegate.cpp" line="209"/>
        <source>%1 views</source>
        <translation>%1 переглядів</translation>
    </message>
    <message>
        <location filename="src/playlistitemdelegate.cpp" line="309"/>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 з %2 (%3) — %4</translation>
    </message>
    <message>
        <location filename="src/playlistitemdelegate.cpp" line="316"/>
        <source>Preparing</source>
        <translation>Підготовка</translation>
    </message>
    <message>
        <location filename="src/playlistitemdelegate.cpp" line="318"/>
        <source>Failed</source>
        <translation>Невдача</translation>
    </message>
    <message>
        <location filename="src/playlistitemdelegate.cpp" line="320"/>
        <source>Completed</source>
        <translation>Виконано</translation>
    </message>
    <message>
        <location filename="src/playlistitemdelegate.cpp" line="322"/>
        <source>Stopped</source>
        <translation>Зупинено</translation>
    </message>
    <message>
        <location filename="src/playlistitemdelegate.cpp" line="358"/>
        <source>Stop downloading</source>
        <translation>Зупинити завантаження</translation>
    </message>
    <message>
        <location filename="src/playlistitemdelegate.cpp" line="368"/>
        <source>Show in %1</source>
        <translation>Відтворити у %1</translation>
    </message>
    <message>
        <location filename="src/playlistitemdelegate.cpp" line="370"/>
        <source>Open parent folder</source>
        <translation>Перейти до теки з видивами</translation>
    </message>
    <message>
        <location filename="src/playlistitemdelegate.cpp" line="379"/>
        <source>Restart downloading</source>
        <translation>Завантажити заново</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <location filename="src/playlistmodel.cpp" line="70"/>
        <source>Searching...</source>
        <translation>Пошук...</translation>
    </message>
    <message>
        <location filename="src/playlistmodel.cpp" line="71"/>
        <source>Show %1 More</source>
        <translation>Наступні %1 </translation>
    </message>
    <message>
        <location filename="src/playlistmodel.cpp" line="72"/>
        <source>No videos</source>
        <translation>Нічого не знайдено</translation>
    </message>
    <message>
        <location filename="src/playlistmodel.cpp" line="73"/>
        <source>No more videos</source>
        <translation>Більше немає</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="49"/>
        <source>Sort by</source>
        <translation>Сортувати за</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="53"/>
        <source>Relevance</source>
        <translation>Релевантністю</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="54"/>
        <location filename="src/refinesearchwidget.cpp" line="69"/>
        <source>Date</source>
        <translation>Датою</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="55"/>
        <source>View Count</source>
        <translation>Числом переглядів</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="56"/>
        <source>Rating</source>
        <translation>Рейтинґом</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="73"/>
        <source>Anytime</source>
        <translation>У будь-який час</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="74"/>
        <source>Today</source>
        <translation>Сьогодні</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="75"/>
        <source>7 Days</source>
        <translation>7 днів</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="76"/>
        <source>30 Days</source>
        <translation>30 днів</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="89"/>
        <source>Duration</source>
        <translation>Тривалістю</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="93"/>
        <location filename="src/refinesearchwidget.cpp" line="119"/>
        <source>All</source>
        <translation>Усі</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="94"/>
        <source>Short</source>
        <translation>Короткі</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="95"/>
        <source>Medium</source>
        <translation>Середні</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="96"/>
        <source>Long</source>
        <translation>Довгі</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="99"/>
        <source>Less than 4 minutes</source>
        <translation>Коротші за 4 хвилини</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="100"/>
        <source>Between 4 and 20 minutes</source>
        <translation>Між 4 та 20 хвилинами</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="101"/>
        <source>Longer than 20 minutes</source>
        <translation>Довші, аніж 20 хвилин</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="115"/>
        <source>Quality</source>
        <translation>Якість</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="120"/>
        <source>High Definition</source>
        <translation>Висока роздільна здатність</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="123"/>
        <source>720p or higher</source>
        <translation>720p або більше</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="136"/>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <location filename="src/regionsview.cpp" line="39"/>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <location filename="src/searchlineedit.cpp" line="55"/>
        <source>Search</source>
        <translation>Шукати</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <location filename="src/searchview.cpp" line="83"/>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Ласкаво просимо до &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <location filename="src/searchview.cpp" line="200"/>
        <source>Get the full version</source>
        <translation>Отримати повну версію</translation>
    </message>
    <message>
        <location filename="src/searchview.cpp" line="110"/>
        <source>Enter</source>
        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole phrase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
        <translation>Уведіть</translation>
    </message>
    <message>
        <location filename="src/searchview.cpp" line="117"/>
        <source>a keyword</source>
        <translation>запит</translation>
    </message>
    <message>
        <location filename="src/searchview.cpp" line="118"/>
        <source>a channel</source>
        <translation>канал</translation>
    </message>
    <message>
        <location filename="src/searchview.cpp" line="125"/>
        <source>to start watching videos.</source>
        <translation>аби розпочати перегляд.</translation>
    </message>
    <message>
        <location filename="src/searchview.cpp" line="156"/>
        <source>Watch</source>
        <translation>Дивитися</translation>
    </message>
    <message>
        <location filename="src/searchview.cpp" line="174"/>
        <source>Recent keywords</source>
        <translation>Нещодавній пошук</translation>
    </message>
    <message>
        <location filename="src/searchview.cpp" line="186"/>
        <source>Recent channels</source>
        <translation>Останні канали</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <location filename="src/sidebarheader.cpp" line="38"/>
        <location filename="src/sidebarheader.cpp" line="45"/>
        <source>&amp;Back</source>
        <translation>Н&amp;азад</translation>
    </message>
    <message>
        <location filename="src/sidebarheader.cpp" line="76"/>
        <source>Forward to %1</source>
        <translation>Уперед до %1</translation>
    </message>
    <message>
        <location filename="src/sidebarheader.cpp" line="89"/>
        <source>Back to %1</source>
        <translation>Назад до %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <location filename="src/sidebarwidget.cpp" line="68"/>
        <source>Refine Search</source>
        <translation>Уточнити пошук</translation>
    </message>
    <message>
        <location filename="src/sidebarwidget.cpp" line="167"/>
        <source>Did you mean: %1</source>
        <translation>Можливо, Ви мали на увазі: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <location filename="src/snapshotsettings.cpp" line="47"/>
        <source>Change location...</source>
        <translation>Змінити теку для завантаження...</translation>
    </message>
    <message>
        <location filename="src/snapshotsettings.cpp" line="64"/>
        <source>Snapshot saved to %1</source>
        <translation>Зняток збережено в %1</translation>
    </message>
    <message>
        <location filename="src/snapshotsettings.cpp" line="117"/>
        <source>Snapshots location changed.</source>
        <translation>Місцезнаходження знятків змінено.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <location filename="src/standardfeedsview.cpp" line="107"/>
        <source>Most Popular</source>
        <translation>Найпопулярніші</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <location filename="src/video.cpp" line="287"/>
        <source>Cannot get video stream for %1</source>
        <translation>Не вдалося отримати видивопотік для %1</translation>
    </message>
    <message>
        <location filename="src/video.cpp" line="292"/>
        <source>Network error: %1 for %2</source>
        <translation>Помилка мережі: %1 для %2</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <location filename="src/ytregions.cpp" line="28"/>
        <source>Algeria</source>
        <translation>Алжир</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="29"/>
        <source>Argentina</source>
        <translation>Аргентина</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="30"/>
        <source>Australia</source>
        <translation>Австралія</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="31"/>
        <source>Belgium</source>
        <translation>Бельґія</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="32"/>
        <source>Brazil</source>
        <translation>Бразилія</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="33"/>
        <source>Canada</source>
        <translation>Канада</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="34"/>
        <source>Chile</source>
        <translation>Чилі</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="35"/>
        <source>Colombia</source>
        <translation>Колумбія</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="36"/>
        <source>Czech Republic</source>
        <translation>Чехія</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="37"/>
        <source>Egypt</source>
        <translation>Єгипет</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="38"/>
        <source>France</source>
        <translation>Франція</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="39"/>
        <source>Germany</source>
        <translation>Німеччина</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="40"/>
        <source>Ghana</source>
        <translation>Ґана</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="41"/>
        <source>Greece</source>
        <translation>Ґреція</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="42"/>
        <source>Hong Kong</source>
        <translation>Гонконґ</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="43"/>
        <source>Hungary</source>
        <translation>Угорщина</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="44"/>
        <source>India</source>
        <translation>Індія</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="45"/>
        <source>Indonesia</source>
        <translation>Індонезія</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="46"/>
        <source>Ireland</source>
        <translation>Ірландія</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="47"/>
        <source>Israel</source>
        <translation>Ізраїль</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="48"/>
        <source>Italy</source>
        <translation>Італія</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="49"/>
        <source>Japan</source>
        <translation>Японія</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="50"/>
        <source>Jordan</source>
        <translation>Йорданія</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="51"/>
        <source>Kenya</source>
        <translation>Кенія</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="52"/>
        <source>Malaysia</source>
        <translation>Малайзія</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="53"/>
        <source>Mexico</source>
        <translation>Мексика</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="54"/>
        <source>Morocco</source>
        <translation>Марокко</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="55"/>
        <source>Netherlands</source>
        <translation>Нідерланди</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="56"/>
        <source>New Zealand</source>
        <translation>Нова Зеландія</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="57"/>
        <source>Nigeria</source>
        <translation>Ніґерія</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="58"/>
        <source>Peru</source>
        <translation>Перу</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="59"/>
        <source>Philippines</source>
        <translation>Філіппіни</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="60"/>
        <source>Poland</source>
        <translation>Польща</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="61"/>
        <source>Russia</source>
        <translation>Російська Федерація</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="62"/>
        <source>Saudi Arabia</source>
        <translation>Саудівська Аравія</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="63"/>
        <source>Singapore</source>
        <translation>Синґапур</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="64"/>
        <source>South Africa</source>
        <translation>ПАР</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="65"/>
        <source>South Korea</source>
        <translation>Республіка Корея</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="66"/>
        <source>Spain</source>
        <translation>Іспанія</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="67"/>
        <source>Sweden</source>
        <translation>Швеція</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="68"/>
        <source>Taiwan</source>
        <translation>Тайвань</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="69"/>
        <source>Tunisia</source>
        <translation>Туніс</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="70"/>
        <source>Turkey</source>
        <translation>Туреччина</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="71"/>
        <source>Uganda</source>
        <translation>Уґанда</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="72"/>
        <source>United Arab Emirates</source>
        <translation>ОАЕ</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="73"/>
        <source>United Kingdom</source>
        <translation>Великобританія</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="74"/>
        <source>Yemen</source>
        <translation>Ємен</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="148"/>
        <source>Worldwide</source>
        <translation>Світовий</translation>
    </message>
</context>
</TS>